@@ -2,7 +2,7 @@
 
 DATA_DIR=/data
 
-if [ -L "$DATA_DIR" ] && [ $2 != "force" ] ; then
+if [ -L "$DATA_DIR" ] && [ "$2" != "force" ] ; then
    echo "$DATA_DIR link exists, use force parameter to override" 1>&2
    exit 1
 fi
